import { Client, Plugin, PluginManifest, PluginModules } from "@web3api/core-js";
import { Signer, ethers } from "ethers";
import { ExternalProvider, JsonRpcProvider, Web3Provider } from "@ethersproject/providers";
export declare type Address = string;
export declare type AccountIndex = number;
export declare type EthereumSigner = Signer | Address | AccountIndex;
export declare type EthereumProvider = string | ExternalProvider;
export declare type EthereumClient = JsonRpcProvider | Web3Provider;
export interface EthereumConfig {
    provider: EthereumProvider;
    signer?: EthereumSigner;
}
export declare class EthereumPlugin extends Plugin {
    private _config;
    private _client;
    constructor(_config: EthereumConfig);
    static manifest(): PluginManifest;
    getModules(_client: Client): PluginModules;
    setProvider(provider: EthereumProvider, signer?: EthereumSigner): void;
    setSigner(signer: EthereumSigner): void;
    getSigner(): ethers.Signer;
    getContract(address: Address, abi: string[]): ethers.Contract;
    deployContract(abi: ethers.ContractInterface, bytecode: string, ...args: unknown[]): Promise<Address>;
    callView(address: Address, method: string, args: string[]): Promise<string>;
    sendTransaction(address: Address, method: string, args: string[]): Promise<string>;
}
